#!/usr/bin/perl
# Copyright (c) 2008, Rob Bloom
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the <organization> nor the
#       names of its contributors may be used to endorse or promote products
#       derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY ROB BLOOM ''AS IS'' AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL ROB BLOOM BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#


use strict;
use Image::Magick;
use Image::RGBA;
use Audio::Wav;

my $img = new Image::Magick;
$img->Read('input.png');
my $col = new Image::RGBA(sample => 'simple', image => $img);

my $wav = new Audio::Wav;

my $details = {
	'bits_sample' => 16,
	'sample_rate' => 44100,
	'channels' => 1
};

my $out = $wav->write('out.wav', $details);

my $w = $img->Get('width');
my $h = $img->Get('height');

print "Input image is $w x $h\n";

my $x;
my $y;
for ($y = 0; $y < $h; $y++) {
	for ($x = 0; $x < $w; $x++) {
		my ($r,$g,$b,$a) = unpack('CCCC', $col->Pixel($x,$y));
		$out->write(($r-127.5)*236);
		$out->write(($g-127.5)*236);
		$out->write(($b-127.5)*236);
	}
}

$out->finish();

